@@ -7,10 +7,14 @@ export const SETTING_KEYS = {
   SLIDING_FEE_SCALE: 'invoice.slidingFeeScale',
   INSURER_DEFAUlT_CONTRIBUTION: 'insurer.defaultContribution',
   CUSTOMISATIONS_COMPONENTS: 'customisations.componentVersions',
+  SYNC_ALL_LAB_REQUESTS: 'sync.syncAllLabRequests',
+  SYNC_URGENT_INTERVAL_IN_SECONDS: 'sync.urgentIntervalInSeconds',
+  INTEGRATIONS_IMAGING: 'integrations.imaging',
+  FEATURES_DESKTOP_CHARTING_ENABLED: 'features.desktopCharting.enabled',
 };
 
 export const SETTINGS_SCOPES = {
   CENTRAL: 'central',
   GLOBAL: 'global',
   FACILITY: 'facility',
-};
+} as const;
