@@ -42,6 +42,12 @@ patientRoute.get(
     });
     if (!patient) throw new NotFoundError();
 
+    await req.audit.access({
+      recordId: params.id,
+      params,
+      model: Patient,
+    });
+
     res.send(dbRecordToResponse(patient, facilityId));
   }),
 );
@@ -156,6 +162,7 @@ patientRoute.get(
     const {
       models: { Encounter },
       params,
+      query: { facilityId },
     } = req;
 
     req.checkPermission('read', 'Patient');
@@ -169,6 +176,15 @@ patientRoute.get(
       include: Encounter.getFullReferenceAssociations(),
     });
 
+    if (currentEncounter) {
+      await req.audit.access({
+        recordId: currentEncounter.id,
+        params,
+        model: Encounter,
+        facilityId,
+      });
+    }
+
     // explicitly send as json (as it might be null)
     res.json(currentEncounter);
   }),
@@ -222,7 +238,7 @@ patientRoute.get(
     });
 
     const { count } = lastEncounterMedications;
-    const data = lastEncounterMedications.rows.map(x => x.forResponse());
+    const data = lastEncounterMedications.rows.map((x) => x.forResponse());
 
     res.send({
       count,
@@ -253,14 +269,14 @@ patientRoute.get(
       PATIENT_SORT_KEYS.firstName,
       PATIENT_SORT_KEYS.displayId,
     ]
-      .filter(v => v !== orderBy)
-      .map(v => `${v} ASC`)
+      .filter((v) => v !== orderBy)
+      .map((v) => `${v} ASC`)
       .join(', ');
 
     // query is always going to come in as strings, has to be set manually
     ['ageMax', 'ageMin']
-      .filter(k => filterParams[k])
-      .forEach(k => {
+      .filter((k) => filterParams[k])
+      .forEach((k) => {
         filterParams[k] = parseFloat(filterParams[k]);
       });
 
@@ -277,7 +293,7 @@ patientRoute.get(
     // 2.d) the same rule of 2.b is applied in case we have two or more columns starting with what the user selected.
     // 2.e) The last rule for selected filters, is, if the user has selected any of those filters, we should also sort them alphabetically.
     if (!orderBy) {
-      const selectedFilters = ['displayId', 'lastName', 'firstName'].filter(v => filterParams[v]);
+      const selectedFilters = ['displayId', 'lastName', 'firstName'].filter((v) => filterParams[v]);
       if (selectedFilters?.length) {
         filterSortReplacements = selectedFilters.reduce((acc, filter) => {
           return {
@@ -290,18 +306,20 @@ patientRoute.get(
         // Exact match sort
         const exactMatchSort = selectedFilters
           .map(
-            filter => `upper(patients.${snakeCase(filter)}) = ${`:exactMatchSort${filter}`} DESC`,
+            (filter) => `upper(patients.${snakeCase(filter)}) = ${`:exactMatchSort${filter}`} DESC`,
           )
           .join(', ');
 
         // Begins with sort
         const beginsWithSort = selectedFilters
-          .map(filter => `upper(patients.${snakeCase(filter)}) LIKE :beginsWithSort${filter} DESC`)
+          .map(
+            (filter) => `upper(patients.${snakeCase(filter)}) LIKE :beginsWithSort${filter} DESC`,
+          )
           .join(', ');
 
         // the last one is
         const alphabeticSort = selectedFilters
-          .map(filter => `patients.${snakeCase(filter)} ASC`)
+          .map((filter) => `patients.${snakeCase(filter)} ASC`)
           .join(', ');
 
         filterSort = `${exactMatchSort}, ${beginsWithSort}, ${alphabeticSort}`;
@@ -437,8 +455,9 @@ patientRoute.get(
         ${select}
         ${from}
 
-        ORDER BY  ${filterSort &&
-          `${filterSort},`} ${sortKey} ${sortDirection}, ${secondarySearchTerm} NULLS LAST
+        ORDER BY  ${
+          filterSort && `${filterSort},`
+        } ${sortKey} ${sortDirection}, ${secondarySearchTerm} NULLS LAST
         LIMIT :limit
         OFFSET :offset
       `,
@@ -455,7 +474,7 @@ patientRoute.get(
       },
     );
 
-    const forResponse = result.map(x => renameObjectKeys(x.forResponse()));
+    const forResponse = result.map((x) => renameObjectKeys(x.forResponse()));
 
     res.send({
       data: forResponse,
