@@ -6,7 +6,11 @@ export const patientBirthData = express.Router();
 patientBirthData.get(
   '/:id/birthData',
   asyncHandler(async (req, res) => {
-    const { models, params } = req;
+    const {
+      models,
+      params,
+      query: { facilityId },
+    } = req;
 
     req.checkPermission('read', 'Patient');
 
@@ -16,6 +20,15 @@ patientBirthData.get(
 
     const recordData = birthDataRecord ? birthDataRecord.toJSON() : {};
 
+    if (birthDataRecord) {
+      await req.audit.access({
+        recordId: birthDataRecord.id,
+        params,
+        model: models.PatientBirthData,
+        facilityId,
+      });
+    }
+
     res.send({ ...recordData });
   }),
 );
