@@ -1,5 +1,6 @@
 import _config from 'config';
 import { log } from '@tamanu/shared/services/logging';
+import { AUDIT_PAUSE_KEY } from '@tamanu/constants';
 import {
   FACT_CURRENT_SYNC_TICK,
   FACT_LAST_SUCCESSFUL_SYNC_PULL,
@@ -233,6 +234,7 @@ export class FacilitySyncManager {
 
     await this.sequelize.transaction(async () => {
       if (totalPulled > 0) {
+        await this.sequelize.setTransactionVar(AUDIT_PAUSE_KEY, true);
         log.info('FacilitySyncManager.savingChanges', { totalPulled });
         await saveIncomingChanges(this.sequelize, getModelsForPull(this.models), sessionId);
       }
